@@ -3,7 +3,7 @@ import sys
 
 # If we are running from a wheel, add the wheel to sys.path
 # This allows the usage python pip-*.whl/pip install pip-*.whl
-if __package__ == '':
+if __package__ == "":
     # __file__ is traffic-*.whl/traffic/__main__.py
     # first dirname call strips of '/__main__.py', second strips off '/pip'
     # Resulting path is the name of the wheel itself
@@ -13,5 +13,5 @@ if __package__ == '':
 
 from traffic.console import main as _main  # noqa
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(_main())
