@@ -1,19 +1,25 @@
-# fmt: off
-
 import logging
 import warnings
 from datetime import timedelta
 from pathlib import Path
 from typing import (
-    TYPE_CHECKING, Any, Callable, Dict, Iterable, Iterator,
-    List, Optional, Set, Type, TypeVar, Union, overload
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Set,
+    Type,
+    TypeVar,
+    Union,
+    overload,
 )
 
 import pandas as pd
 import pyproj
-from cartopy import crs
-from cartopy.mpl.geoaxes import GeoAxesSubplot
-from matplotlib.artist import Artist
 from shapely.geometry import Polygon, base
 
 from ..algorithms.clustering import Clustering, centroid
@@ -26,13 +32,17 @@ from .mixins import GeographyMixin, HBoxMixin, PointMixin
 from .sv import StateVectors
 
 if TYPE_CHECKING:
+    from cartopy import crs
+    from cartopy.mpl.geoaxes import GeoAxesSubplot
+    from matplotlib.artist import Artist
+
     from ..algorithms.clustering import (  # noqa: F401
-        ClusteringProtocol, TransformerProtocol
+        ClusteringProtocol,
+        TransformerProtocol,
     )
     from ..algorithms.cpa import CPA  # noqa: F401
     from .airspace import Airspace  # noqa: F401
 
-# fmt: on
 
 # https://github.com/python/mypy/issues/2511
 TrafficTypeVar = TypeVar("TrafficTypeVar", bound="Traffic")
@@ -770,7 +780,7 @@ class Traffic(HBoxMixin, GeographyMixin):
         raise NotImplementedError
 
     def plot(
-        self, ax: GeoAxesSubplot, nb_flights: Optional[int] = None, **kwargs
+        self, ax: "GeoAxesSubplot", nb_flights: Optional[int] = None, **kwargs
     ) -> None:  # coverage: ignore
         """Plots each trajectory on a Matplotlib axis.
 
@@ -885,12 +895,12 @@ class Traffic(HBoxMixin, GeographyMixin):
 
     def plot_wind(
         self,
-        ax: GeoAxesSubplot,
+        ax: "GeoAxesSubplot",
         resolution: Union[Dict[str, float], None] = None,
         threshold: int = 10,
         filtered: bool = False,
         **kwargs,
-    ) -> List[Artist]:  # coverage: ignore
+    ) -> List["Artist"]:  # coverage: ignore
         """Plots the wind field seen by the aircraft on a Matplotlib axis.
 
         The Flight supports Cartopy axis as well with automatic projection. If
@@ -920,6 +930,8 @@ class Traffic(HBoxMixin, GeographyMixin):
 
         """
 
+        from cartopy import crs
+
         if "projection" in ax.__dict__ and "transform" not in kwargs:
             kwargs["transform"] = crs.PlateCarree()
 
@@ -997,7 +1009,7 @@ class Traffic(HBoxMixin, GeographyMixin):
         self,
         lateral_separation: float,
         vertical_separation: float,
-        projection: Union[pyproj.Proj, crs.Projection, None] = None,
+        projection: Union[pyproj.Proj, "crs.Projection", None] = None,
         round_t: str = "d",
         max_workers: int = 4,
     ) -> Optional["CPA"]:
@@ -1056,7 +1068,7 @@ class Traffic(HBoxMixin, GeographyMixin):
         nb_samples: Optional[int],
         features: Optional[List[str]] = None,
         *args,
-        projection: Union[None, crs.Projection, pyproj.Proj] = None,
+        projection: Union[None, "crs.Projection", pyproj.Proj] = None,
         transform: Optional["TransformerProtocol"] = None,
         max_workers: int = 1,
         return_traffic: bool = True,
@@ -1125,7 +1137,7 @@ class Traffic(HBoxMixin, GeographyMixin):
         self,
         nb_samples: Optional[int],
         features: Optional[List[str]] = None,
-        projection: Union[None, crs.Projection, pyproj.Proj] = None,
+        projection: Union[None, "crs.Projection", pyproj.Proj] = None,
         transformer: Optional["TransformerProtocol"] = None,
         max_workers: int = 1,
         *args,
