@@ -1,4 +1,3 @@
-# fmt: off
 import json
 import logging
 import os
@@ -10,15 +9,23 @@ from functools import lru_cache
 from io import StringIO
 from pathlib import Path
 from typing import (
-    Dict, Iterable, Iterator, List, NoReturn, Optional,
-    Set, Tuple, Type, TypeVar, Union, overload
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    NoReturn,
+    Optional,
+    Set,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+    overload,
 )
 
 import numpy as np
 import pandas as pd
 import pyproj
-from cartopy.crs import PlateCarree
-from scipy.interpolate import interp1d
 from shapely.geometry import LineString, base
 
 from ....core import Airspace
@@ -27,8 +34,6 @@ from ....core.flight import Position
 from ....core.mixins import DataFrameMixin
 from ....core.time import time_or_delta, timelike, to_datetime
 
-# fmt: on
-
 
 def _prepare_libarchive():  # coverage: ignore
     """
@@ -249,7 +254,12 @@ class Flight(FlightMixin):
         """Identity method, available for consistency"""
         return self
 
-    def interpolate(self, times, proj=PlateCarree()) -> np.ndarray:
+    def interpolate(self, times, proj=None) -> np.ndarray:
+        from cartopy.crs import PlateCarree
+        from scipy.interpolate import interp1d
+
+        if proj is None:
+            proj = PlateCarree()
         if proj not in self.interpolator:
             self.interpolator[proj] = interp1d(
                 np.stack(
